authentication.py — Rucio 1.12.2 documentation

# authentication.py

`OPTIONS` `/auth/userpass/userpass`

  > HTTP Success:

  Example request:

      OPTIONS /auth/userpass/userpass HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type:

`GET` `/auth/userpass/userpass`

  > HTTP Success:

  Example request:

      GET /auth/userpass/userpass HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type:

  Status Codes: | 401 Unauthorized – ‘CannotAuthenticate’: ‘Cannot authenticate to account %(account 500 Internal Server Error – e.__class__.__name__: e.args[0] 401 Unauthorized – ‘CannotAuthenticate’: ‘Cannot authenticate to account %(account

`OPTIONS` `/auth/gss/gss`

  > HTTP Success:

  Example request:

      OPTIONS /auth/gss/gss HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type:

`OPTIONS` `/auth/x509/x509_proxy/x509/x509_proxy`

  > HTTP Success:

  Example request:

      OPTIONS /auth/x509/x509_proxy/x509/x509_proxy HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type:

`GET` `/auth/x509/x509_proxy/x509/x509_proxy`

  > HTTP Success:

  Example request:

      GET /auth/x509/x509_proxy/x509/x509_proxy HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type:

  Status Codes: | 401 Unauthorized – ‘CannotAuthenticate’: ‘Cannot get DN’ 401 Unauthorized – ‘CannotAuthenticate’: ‘Cannot authenticate to account %(account 401 Unauthorized – ‘CannotAuthenticate’: ‘No default account set for %(dn 401 Unauthorized – ‘CannotAuthenticate’: ‘Cannot authenticate to account %(account

`OPTIONS` `/auth/validate/validate`

  > HTTP Success:

  Example request:

      OPTIONS /auth/validate/validate HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type:

`GET` `/auth/validate/validate`

  > HTTP Success:

  Example request:

      GET /auth/validate/validate HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type:

  Status Codes: | 401 Unauthorized – ‘CannotAuthenticate’: ‘Cannot authenticate to account %(account